==> gitlab_12.6.4.orig.tar.gz: gitlab-foss-v12.6.4/app/controllers/projects/registry/repositories_controller.rb <==
# frozen_string_literal: true

module Projects
  module Registry
    class RepositoriesController < ::Projects::Registry::ApplicationController
      before_action :authorize_update_container_image!, only: [:destroy]
      before_action :ensure_root_container_repository!, only: [:index]

      def index
        @images = project.container_repositories
        track_event(:list_repositories)

        respond_to do |format|
          format.html
          format.json do
            render json: ContainerRepositoriesSerializer
              .new(project: project, current_user: current_user)
              .represent(@images)
          end
        end
      end

      def destroy
        DeleteContainerRepositoryWorker.perform_async(current_user.id, image.id)
        track_event(:delete_repository)

        respond_to do |format|
          format.json { head :no_content }
        end
      end

      private

      def image
        @image ||= project.container_repositories.find(params[:id])
      end

      ##
      # Container repository object for root project path.
      #
      # Needed to maintain a backwards compatibility.
      #
      def ensure_root_container_repository!
        ::ContainerRegistry::Path.new(@project.full_path).tap do |path|
          break if path.has_repository?

          ::ContainerRepository.build_from_path(path).tap do |repository|
            repository.save! if repository.has_tags?
          end
        end
      rescue ContainerRegistry::Path::InvalidRegistryPathError
        @character_error = true
      end
    end
  end
end

==> gitlab_12.8.8.orig.tar.gz: gitlab-foss-v12.8.8/app/controllers/projects/registry/repositories_controller.rb <==
# frozen_string_literal: true

module Projects
  module Registry
    class RepositoriesController < ::Projects::Registry::ApplicationController
      before_action :authorize_update_container_image!, only: [:destroy]
      before_action :ensure_root_container_repository!, only: [:index]

      def index
        respond_to do |format|
          format.html
          format.json do
            @images = project.container_repositories

            track_event(:list_repositories)

            serializer = ContainerRepositoriesSerializer
              .new(project: project, current_user: current_user)

            if Feature.enabled?(:vue_container_registry_explorer)
              render json: serializer.with_pagination(request, response).represent(@images)
            else
              render json: serializer.represent(@images)
            end
          end
        end
      end

      # The show action renders index to allow frontend routing to work on page refresh
      def show
        render :index
      end

      def destroy
        DeleteContainerRepositoryWorker.perform_async(current_user.id, image.id) # rubocop:disable CodeReuse/Worker
        track_event(:delete_repository)

        respond_to do |format|
          format.json { head :no_content }
        end
      end

      private

      def image
        @image ||= project.container_repositories.find(params[:id])
      end

      ##
      # Container repository object for root project path.
      #
      # Needed to maintain a backwards compatibility.
      #
      def ensure_root_container_repository!
        ::ContainerRegistry::Path.new(@project.full_path).tap do |path|
          break if path.has_repository?

          ::ContainerRepository.build_from_path(path).tap do |repository|
            repository.save! if repository.has_tags?
          end
        end
      rescue ContainerRegistry::Path::InvalidRegistryPathError
        @character_error = true
      end
    end
  end
end
